@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.51 2004/07/22 17:39:50 sampie Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.53 2004/09/23 16:01:49 sampie Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -24,6 +24,7 @@
 #include <assert.h>
 #include "calctool.h"
 #include "extern.h"
+#include "mpmath.h"
 
 static char *make_eng_sci(int *, int);
 static char *make_fixed(int *, int, int);
@@ -572,30 +573,38 @@ show_display(int *MPval)
 void
 refresh_display()
 {
-    switch (v->syntax) {
-        case npa:
-            show_display(v->MPdisp_val);
-            break;
+  /* In arithmetic precedence mode this
+     routine should be called to redraw display.
+  */
 
-        case exprs:
-            if (v->expression &&
-		strlen(v->expression)) {
-                char *e = gc_strdup(v->expression);
-                char *ans = make_number(v->e.ans, v->base, TRUE, FALSE);
+  char localized[MAX_LOCALIZED];
 
-                str_replace(&e, "Ans", ans);
-                set_display(e, FALSE);
-                free(e);
-            } else {
-	      /* set_display("", FALSE); */
-	      int MP1[MP_SIZE];
-	      do_zero(MP1);
-	      show_display(MP1);
-            }
+  switch (v->syntax) {
+  case npa:
+    show_display(v->MPdisp_val);
+    break;
     
-            break;
-
-        default:
-            assert(0);
+  case exprs:
+    if (v->expression &&
+	strlen(v->expression)) {
+      char *e = gc_strdup(v->expression);
+      char *ans = make_number(v->e.ans, v->base, TRUE, FALSE);
+      localize_number(localized, ans);
+      
+      str_replace(&e, "Ans", localized);
+      //set_display(e, FALSE);
+      write_display(e);
+      free(e);
+    } else {
+      /* set_display("", FALSE); */
+      int MP1[MP_SIZE];
+      do_zero(MP1);
+      show_display(MP1);
     }
+    
+    break;
+    
+  default:
+    assert(0);
+  }
 }
